package com.ruoyi.powerdistribution.service;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmReportPlanNextDay;

/**
 * 明日工作计划Service接口
 *
 * @author ruoyi
 * @date 2024-11-28
 */
public interface IPdmReportPlanNextDayService
{
    /**
     * 查询明日工作计划
     *
     * @param id 明日工作计划主键
     * @return 明日工作计划
     */
    public PdmReportPlanNextDay selectPdmReportPlanNextDayById(Long id);

    /**
     * 查询明日工作计划列表
     *
     * @param pdmReportPlanNextDay 明日工作计划
     * @return 明日工作计划集合
     */
    public List<PdmReportPlanNextDay> selectPdmReportPlanNextDayList(PdmReportPlanNextDay pdmReportPlanNextDay);

    /**
     * 新增明日工作计划
     *
     * @param pdmReportPlanNextDay 明日工作计划
     * @return 结果
     */
    public int insertPdmReportPlanNextDay(PdmReportPlanNextDay pdmReportPlanNextDay);

    /**
     * 修改明日工作计划
     *
     * @param pdmReportPlanNextDay 明日工作计划
     * @return 结果
     */
    public int updatePdmReportPlanNextDay(PdmReportPlanNextDay pdmReportPlanNextDay);

    /**
     * 批量删除明日工作计划
     *
     * @param ids 需要删除的明日工作计划主键集合
     * @return 结果
     */
    public int deletePdmReportPlanNextDayByIds(Long[] ids);

    /**
     * 删除明日工作计划信息
     *
     * @param id 明日工作计划主键
     * @return 结果
     */
    public int deletePdmReportPlanNextDayById(Long id);
}
